%undefine __cmake_in_source_build

%global soversion 10.1

%global with_tests 0

%global with_openexr 1
%global with_ax      0

Name:           openvdb
Version:        10.1.0
Release:    1%{?dist}
Summary:        C++ library for sparse volumetric data discretized on three-dimensional grids
License:        MPL-2.0
URL:            http://www.openvdb.org/

Source0:        https://github.com/AcademySoftwareFoundation/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  boost-devel >= 1.61
BuildRequires:  cmake >= 2.8
BuildRequires:  doxygen >= 1.8.11
BuildRequires:  gcc-c++
BuildRequires:  ghostscript >= 8.70
BuildRequires:  libstdc++-devel
%if 0%{?with_ax}
BuildRequires:	llvm-devel
BuildRequires:	pkgconfig(libffi)
%endif
BuildRequires:  pkgconfig(blosc) >= 1.5.0
BuildRequires:  pkgconfig(cppunit) >= 1.10
BuildRequires:  pkgconfig(glfw3) >= 2.7
BuildRequires:  pkgconfig(jemalloc)
BuildRequires:  pkgconfig(log4cplus) >= 1.0
BuildRequires:  cmake(pybind11)
%if 0%{?with_openexr}
BuildRequires:  pkgconfig(OpenEXR) >= 3.0
%endif
BuildRequires:  pkgconfig(tbb) >= 3.0
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(zlib) > 1.2.7

%description
OpenVDB is an Academy Award-winning open-source C++ library comprising a novel
hierarchical data structure and a suite of tools for the efficient storage and
manipulation of sparse volumetric data discretized on three-dimensional grids.
It is developed and maintained by Academy Software Foundation for use in
volumetric applications typically encountered in feature film production.

This package contains some graphical tools.

%package        libs
Summary:        Core OpenVDB libraries

%description    libs
OpenVDB is an Academy Award-winning open-source C++ library comprising a novel
hierarchical data structure and a suite of tools for the efficient storage and
manipulation of sparse volumetric data discretized on three-dimensional grids.
It is developed and maintained by Academy Software Foundation for use in
volumetric applications typically encountered in feature film production.

%package        devel
Summary:        Development files for %{name}
BuildRequires:  texlive-latex
Requires:       %{name}-libs = %{version}-%{release}
Requires:       pkgconfig(tbb) >= 3.0
Requires:       pkgconfig(zlib) > 1.2.7
Provides:       %{name}-doc = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.

%package        -n python3-%{name}
Summary:        OpenVDB Python module
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(numpy)
Requires:       %{name}-libs = %{version}-%{release}

%description    -n python3-%{name}
%{description}

This package contains the Python module.


%prep
%autosetup -p1

sed -i \
    -e 's|lib$|%{_lib}|g' \
    %{name}/%{name}/CMakeLists.txt %{name}/%{name}/python/CMakeLists.txt


%build
export CXXFLAGS="%{build_cxxflags} -Wl,--as-needed"

%cmake \
    -DCMAKE_NO_SYSTEM_FROM_IMPORTED=TRUE \
    -DDISABLE_DEPENDENCY_VERSION_CHECKS=ON \
    -DOPENVDB_BUILD_DOCS=ON \
    -DOPENVDB_BUILD_PYTHON_MODULE=ON \
    -DOPENVDB_BUILD_UNITTESTS=OFF \
    -DOPENVDB_ENABLE_RPATH=OFF \
    -DPYOPENVDB_INSTALL_DIRECTORY=%{python3_sitearch} \
%if 0%{?with_ax}
    -DHAVE_FFI_CALL=ON \
    -DUSE_AX=ON \
%endif
%if 0%{?with_openexr}
    -DUSE_EXR=ON \
%endif
    -DUSE_NANOVDB=ON
%cmake_build

%if 0%{?with_tests}
%check
%ctest test
%endif

%install
%cmake_install

mv %{buildroot}%{_docdir}/OpenVDB/html .
rm -fr %{buildroot}%{_datadir}/doc

find %{buildroot} -name '*.a' -delete

%files
%{_bindir}/vdb_print
%{_bindir}/nanovdb_{print,validate}

%files libs
%license LICENSE
%doc README.md CHANGES
%{_libdir}/lib%{name}.so.%{version}
%{_libdir}/lib%{name}.so.%{soversion}

%files -n python3-%{name}
%{python3_sitearch}/py%{name}.cpython-*.so

%files devel
%doc html
%{_includedir}/*
%{_libdir}/lib%{name}.so
%{_libdir}/cmake/OpenVDB/

%changelog
* Wed Jul 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 10.1.0-1
- initial build
